浙江省淡水水产研究所

内网入口
内网入口

- 首页
- 研究所概况
  - 研究所介绍
  - 所级领导
  - 机构设置
  - 创新载体
  - 领导关怀
  - 所容所貌
  - 联系我们
- 人才培养
  - 科研队伍
- 科学研究
  - 研究领域
  - 科研成果
  - 科研进展
- 成果转化
  - 新品种新技术
  - 新成果
  - 转化进展
- 公共服务
  - 科技特派员
  - 技术服务
- 合作交流
- 党群园地

首页 >重要信息

##### 浙江省淡水水产研究所召开干部职工大会暨党风廉政建设大会

21
2024年02月
分享

为贯彻落实省农业农村厅干部职工大会精神，2月19日下午，浙江省淡水水产研究所召开干部职工大会暨党风廉政建设大会。会议传达了王通林厅长重要讲话精神，全体职工观看了廉政警示教育片，层层签订了党风廉政建设责任书。会议要求，全所干部职工要围绕农业科技创新工作，比学赶超、奋勇争先，以“开局就要奔跑、起步就要跃进”的姿态迅速投入工作；对照干部队伍建设8个“还有之”和党风廉政建设5个“还有之”开展查摆自纠。一要把好方向盘厘清工作思路，明确主次，确保重要工作做踏实、细小工作不遗漏；二要紧盯绩效表抓好工作落实，树牢问题导向和目标导向，坚持“主动想、重点干、善协调、出经验”工作理念，鼓励全所干部职工创先争优，全力打造第一等的标志性成果；三要拧紧安全阀守牢工作底线，按照无规定疫病苗种场的建设要求，扎实做好水生动物疫病防控工作，确保种源生物安全，从实从细抓好安全生产工作和党风廉政建设，营造清正廉洁、干净干事的良好氛围。

返回列表
首页 >重要信息
相关推荐
陈浩调研粮食安全和现代农业发展：守牢粮食安全底线 大力发展现代农业
浙江省淡水水产研究所在衢州开展罗氏沼虾良种良法推广

- 2020年01月18日
  淡水水产所召开退休老同志情况通报会
- 2025年06月26日
  浙江省淡水水产研究所成功研发大黄鱼锥体虫病防治药物
- 2025年06月13日
  澳大利亚HopeVale基金会代表访问浙江省淡水水产研究所

分享到微信朋友圈
打开微信，点击底部的"发现",
使用"扫一扫"即可将网页分至朋友圈。